package com.lange.bluetooth_printer;

import android.content.Context;

import java.util.ArrayList;
import java.util.List;

import am.util.printer.PrintDataMaker;
import am.util.printer.PrinterWriter;
import am.util.printer.PrinterWriter58mm;
import am.util.printer.PrinterWriter80mm;

/**
 * 测试数据生成器
 * Created by Alex on 2016/11/10.
 */

public class OrderPrintDataMaker implements PrintDataMaker {

    private int width = 300;
    private int height = 255;
    private OrderModel orderModel;

    OrderPrintDataMaker(OrderModel orderModel) {
        this.orderModel = orderModel;
    }

    @Override
    public List<byte[]> getPrintData(int type) {
        ArrayList<byte[]> data = new ArrayList<>();
        try {
            PrinterWriter printer;
            printer = type == PrinterWriter58mm.TYPE_58 ? new PrinterWriter58mm(height, width) : new PrinterWriter80mm(height, width);
            printer.setAlignCenter();
            printer.setFontSize(1);
            printer.print("#" + orderModel.getCode() + orderModel.getPlatformName());
            printer.printLineFeed();
            printer.setFontSize(0);
            printer.print(orderModel.getMerchantName());
            printer.printLineFeed();
            printer.setAlignCenter();
            printer.print("已在线支付");

            printer.setAlignLeft();
            printer.printLineFeed();
            if (orderModel.getExpectedTime() == null) {
                printer.print("期望送达时间：" + "立即送达");
            } else {
                printer.print("期望送达时间：" + orderModel.getExpectedTime());
            }
            printer.printLineFeed();
            printer.print("下单时间：" + orderModel.getCreateTime());
            printer.printLineFeed();
            printer.print("订单号：" + orderModel.getOrderId());
            printer.printLineFeed();

            printer.print(getImaginaryLine());

            /*商品*/
            for (OrderModel.Detail detail : orderModel.getDetails()) {
                double price = detail.isSpecial() ? detail.getSpecialPrice() : detail.getPrice();
                printer.setAlignLeft();
                printer.print(detail.getProductName());
                printer.printLineFeed();
                String weightStr = "" + detail.getWeight();
                String priceStr = "￥" + price;
                String numStr = "x" + detail.getNum();
                printer.print(weightStr + getImaginaryLine(16 - (numStr.length() / 2) - weightStr.length()) + numStr
                        + getImaginaryLine(16 - (numStr.length() / 2) - priceStr.length()) + priceStr);
                printer.printLineFeed();
            }

            printer.print(getImaginaryLine());

            //优惠内容
            for (String s : orderModel.getDiscountList()) {
                printer.print(s);
                printer.printLineFeed();
            }

            printer.print(getImaginaryLine());
            //实付
            printer.printLineFeed();
            String totalStr = String.valueOf(orderModel.getTotal());
            printer.print("实付" + getImaginaryLine(32 - 3 - totalStr.length()) + totalStr);
            printer.printLineFeed();

            printer.print(getImaginaryLine());
            //地址
            printer.print("地址：" + orderModel.getAddress());
            printer.printLineFeed();
            printer.print("手机：" + orderModel.getPhone());
            printer.printLineFeed();
            printer.print(getImaginaryLine());


            printer.printLineFeed();
            printer.print(orderModel.getConclusion());
            printer.printLineFeed();

            /*结束*/
            printer.setEmphasizedOff();
            printer.printLineFeed();
            printer.printLineFeed();
            printer.printLineFeed();
            printer.feedPaperCutPartial();
            data.add(printer.getDataAndClose());
            return data;
        } catch (Exception e) {
            return new ArrayList<>();
        }
    }

    /*32个字符*/
    private String getImaginaryLine() {
        return "--------------------------------";
    }

    private String getImaginaryLine(int length) {
        String result = "";
        for (int i = 0; i < length - 1; i++) {
            result += " ";
        }
        return result;
    }
}
